@@ -3,7 +3,9 @@ from spark_auto_mapper_fhir.extensions.extension_base import ExtensionBase
 from spark_auto_mapper_fhir.fhir_types.list import FhirList
 from spark_auto_mapper_fhir.fhir_types.id import FhirId
 
-from spark_auto_mapper_fhir.backbone_elements.fhir_backbone_element_base import FhirBackboneElementBase
+from spark_auto_mapper_fhir.backbone_elements.fhir_backbone_element_base import (
+    FhirBackboneElementBase,
+)
 from spark_auto_mapper_fhir.complex_types.codeableConcept import CodeableConcept
 from spark_auto_mapper_fhir.complex_types.quantity import Quantity
 from spark_auto_mapper_fhir.valuesets.FhirValueSetBase import FhirValueSetBase
@@ -15,7 +17,7 @@ class BenefitLimitBackboneElement(FhirBackboneElementBase):
         id_: Optional[FhirId] = None,
         extension: Optional[FhirList[ExtensionBase]] = None,
         value: Optional[Quantity] = None,
-        code: Optional[CodeableConcept[FhirValueSetBase]] = None
+        code: Optional[CodeableConcept[FhirValueSetBase]] = None,
     ) -> None:
         """
         BenefitLimitBackboneElement Backbone Element in FHIR
