@@ -7,7 +7,9 @@ from spark_auto_mapper_fhir.fhir_types.string import FhirString
 from spark_auto_mapper_fhir.extensions.extension_base import ExtensionBase
 from spark_auto_mapper_fhir.fhir_types.id import FhirId
 from spark_auto_mapper_fhir.fhir_types.list import FhirList
-from spark_auto_mapper_fhir.backbone_elements.fhir_backbone_element_base import FhirBackboneElementBase
+from spark_auto_mapper_fhir.backbone_elements.fhir_backbone_element_base import (
+    FhirBackboneElementBase,
+)
 from spark_auto_mapper_fhir.resources.media import Media
 
 
@@ -23,6 +25,4 @@ class DiagnosticReportMediaBackboneElement(FhirBackboneElementBase):
         DiagnosticReportMediaBackboneElement Backbone Element in FHIR
         https://www.hl7.org/fhir/diagnosticreport-definitions.html#DiagnosticReport.media
         """
-        super().__init__(
-            id_=id_, extension=extension, comment=comment, link=link
-        )
+        super().__init__(id_=id_, extension=extension, comment=comment, link=link)
