@@ -1,6 +1,8 @@
 from typing import Optional
 
-from spark_auto_mapper_fhir.backbone_elements.fhir_backbone_element_base import FhirBackboneElementBase
+from spark_auto_mapper_fhir.backbone_elements.fhir_backbone_element_base import (
+    FhirBackboneElementBase,
+)
 from spark_auto_mapper_fhir.complex_types.reference import Reference
 from spark_auto_mapper_fhir.extensions.extension_base import ExtensionBase
 from spark_auto_mapper_fhir.fhir_types.boolean import FhirBoolean
@@ -18,7 +20,7 @@ class InsuranceBackboneElement(FhirBackboneElementBase):
         coverage: Reference[Coverage],
         id_: Optional[FhirId] = None,
         extension: Optional[FhirList[ExtensionBase]] = None,
-        preAuthRef: Optional[FhirList[FhirString]] = None
+        preAuthRef: Optional[FhirList[FhirString]] = None,
     ):
         """
         InsuranceBackboneElement Resource in FHIR
@@ -35,5 +37,5 @@ class InsuranceBackboneElement(FhirBackboneElementBase):
             extension=extension,
             focal=focal,
             coverage=coverage,
-            preAuthRef=preAuthRef
+            preAuthRef=preAuthRef,
         )
