@@ -6,7 +6,9 @@ from spark_auto_mapper_fhir.fhir_types.string import FhirString
 from spark_auto_mapper_fhir.extensions.extension_base import ExtensionBase
 from spark_auto_mapper_fhir.fhir_types.id import FhirId
 from spark_auto_mapper_fhir.fhir_types.list import FhirList
-from spark_auto_mapper_fhir.backbone_elements.fhir_backbone_element_base import FhirBackboneElementBase
+from spark_auto_mapper_fhir.backbone_elements.fhir_backbone_element_base import (
+    FhirBackboneElementBase,
+)
 
 
 class PlanDefinitionDynamicValueBackboneElement(FhirBackboneElementBase):
@@ -15,7 +17,7 @@ class PlanDefinitionDynamicValueBackboneElement(FhirBackboneElementBase):
         id_: Optional[FhirId] = None,
         extension: Optional[FhirList[ExtensionBase]] = None,
         path: Optional[FhirString] = None,
-        expression: Optional[Expression] = None
+        expression: Optional[Expression] = None,
     ) -> None:
         """
         PlanDefinitionDynamicValueBackboneElement Backbone Element in FHIR
@@ -26,6 +28,4 @@ class PlanDefinitionDynamicValueBackboneElement(FhirBackboneElementBase):
         :param path: The path to the element to be set dynamically
         :param expression: 	An expression that provides the dynamic value for the customization
         """
-        super().__init__(
-            id_=id_, extension=extension, path=path, expression=expression
-        )
+        super().__init__(id_=id_, extension=extension, path=path, expression=expression)
