@@ -8,7 +8,9 @@ from spark_auto_mapper_fhir.fhir_types.date_time import FhirDateTime
 from spark_auto_mapper_fhir.extensions.extension_base import ExtensionBase
 from spark_auto_mapper_fhir.fhir_types.id import FhirId
 from spark_auto_mapper_fhir.fhir_types.list import FhirList
-from spark_auto_mapper_fhir.backbone_elements.fhir_backbone_element_base import FhirBackboneElementBase
+from spark_auto_mapper_fhir.backbone_elements.fhir_backbone_element_base import (
+    FhirBackboneElementBase,
+)
 from spark_auto_mapper_fhir.valuesets.timing_abbreviation import TimingAbbreviationCode
 
 
@@ -19,7 +21,7 @@ class Timing(FhirBackboneElementBase):
         extension: Optional[FhirList[ExtensionBase]] = None,
         event: Optional[FhirList[FhirDateTime]] = None,
         repeat: Optional[TimingRepeat] = None,
-        code: Optional[CodeableConcept[TimingAbbreviationCode]] = None
+        code: Optional[CodeableConcept[TimingAbbreviationCode]] = None,
     ) -> None:
         """
         Timing Backbone Element in FHIR
@@ -32,9 +34,5 @@ class Timing(FhirBackboneElementBase):
         :param code: BID | TID | QID | AM | PM | QD | QOD | +
         """
         super().__init__(
-            id_=id_,
-            extension=extension,
-            event=event,
-            repeat=repeat,
-            code=code
+            id_=id_, extension=extension, event=event, repeat=repeat, code=code
         )
