@@ -4,7 +4,9 @@ from spark_auto_mapper_fhir.extensions.extension_base import ExtensionBase
 
 from spark_auto_mapper_fhir.fhir_types.id import FhirId
 
-from spark_auto_mapper_fhir.backbone_elements.fhir_backbone_element_base import FhirBackboneElementBase
+from spark_auto_mapper_fhir.backbone_elements.fhir_backbone_element_base import (
+    FhirBackboneElementBase,
+)
 
 from spark_auto_mapper_fhir.complex_types.codeableConcept import CodeableConcept
 from spark_auto_mapper_fhir.valuesets.adjudication import AdjudicationCode
@@ -15,7 +17,7 @@ from spark_auto_mapper_fhir.complex_types.money import Money
 class TotalBackBoneElement(FhirBackboneElementBase):
     def __init__(
         self,
-        category: FhirList[CodeableConcept[AdjudicationCode]],
+        category: CodeableConcept[AdjudicationCode],
         amount: Money,
         id_: Optional[FhirId] = None,
         extension: Optional[FhirList[ExtensionBase]] = None,
@@ -28,6 +30,4 @@ class TotalBackBoneElement(FhirBackboneElementBase):
         :param category: Type of adjudication information. https://hl7.org/FHIR/valueset-adjudication.html
         :param amount: Financial total for the category
         """
-        super().__init__(
-            id_=id_, extension=extension, category=category, amount=amount
-        )
+        super().__init__(id_=id_, extension=extension, category=category, amount=amount)
