@@ -6,7 +6,9 @@ from spark_auto_mapper_fhir.fhir_types.list import FhirList
 
 from spark_auto_mapper_fhir.fhir_types.id import FhirId
 
-from spark_auto_mapper_fhir.complex_types.fhir_complex_type_base import FhirComplexTypeBase
+from spark_auto_mapper_fhir.complex_types.fhir_complex_type_base import (
+    FhirComplexTypeBase,
+)
 
 from spark_auto_mapper_fhir.fhir_types.decimal import FhirDecimal
 from spark_auto_mapper_fhir.valuesets.currency import CurrencyCode
@@ -18,7 +20,7 @@ class Money(FhirComplexTypeBase):
         id_: Optional[FhirId] = None,
         extension: Optional[FhirList[ExtensionBase]] = None,
         value: Optional[FhirDecimal] = None,
-        currency: Optional[CurrencyCode] = None
+        currency: Optional[CurrencyCode] = None,
     ):
         """
         Money Resource in FHIR
@@ -28,6 +30,4 @@ class Money(FhirComplexTypeBase):
         :param value: Numerical value (with implicit precision)
         :param currency: ISO 4217 Currency Code. https://hl7.org/FHIR/valueset-currencies.html
         """
-        super().__init__(
-            id_=id_, extension=extension, value=value, currency=currency
-        )
+        super().__init__(id_=id_, extension=extension, value=value, currency=currency)
