@@ -5,7 +5,9 @@ from spark_auto_mapper_fhir.fhir_types.string import FhirString
 from spark_auto_mapper_fhir.extensions.extension_base import ExtensionBase
 from spark_auto_mapper_fhir.fhir_types.id import FhirId
 from spark_auto_mapper_fhir.fhir_types.list import FhirList
-from spark_auto_mapper_fhir.complex_types.fhir_complex_type_base import FhirComplexTypeBase
+from spark_auto_mapper_fhir.complex_types.fhir_complex_type_base import (
+    FhirComplexTypeBase,
+)
 from spark_auto_mapper_fhir.valuesets.sort_direction import SortDirectionCode
 
 
@@ -26,6 +28,4 @@ class Sort(FhirComplexTypeBase):
         :param path: The name of the attribute to perform the sort
         :param direction: 	ascending | descending
         """
-        super().__init__(
-            id_=id_, extension=extension, path=path, direction=direction
-        )
+        super().__init__(id_=id_, extension=extension, path=path, direction=direction)
