@@ -1,7 +1,9 @@
 from typing import Optional
 
 from spark_auto_mapper_fhir.classproperty import genericclassproperty
-from spark_auto_mapper_fhir.extensions.custom.insurance_plan_item import InsurancePlanItemExtension
+from spark_auto_mapper_fhir.extensions.custom.insurance_plan_item import (
+    InsurancePlanItemExtension,
+)
 from spark_auto_mapper_fhir.extensions.extension_base import ExtensionBase
 from spark_auto_mapper_fhir.fhir_types.list import FhirList
 from spark_auto_mapper_fhir.fhir_types.uri import FhirUri
@@ -12,7 +14,7 @@ class InsurancePlanExtension(ExtensionBase):
     def __init__(
         self,
         url: Optional[FhirUri] = None,
-        extension: Optional[FhirList[InsurancePlanItemExtension]] = None
+        extension: Optional[FhirList[InsurancePlanItemExtension]] = None,
     ) -> None:
         """
         InsurancePlanExtension Extension type in FHIR
@@ -21,9 +23,7 @@ class InsurancePlanExtension(ExtensionBase):
         :param url: Automatically set to codeset property if not passed in
         :param extension:
         """
-        super().__init__(
-            url=url or InsurancePlanExtension.codeset, extension=extension
-        )
+        super().__init__(url=url or InsurancePlanExtension.codeset, extension=extension)
 
     # noinspection PyMethodParameters
     @genericclassproperty
