@@ -1,4 +1,6 @@
-from spark_auto_mapper.data_types.complex.complex_base import AutoMapperDataTypeComplexBase
+from spark_auto_mapper.data_types.complex.complex_base import (
+    AutoMapperDataTypeComplexBase,
+)
 
 
 class ExtensionBase(AutoMapperDataTypeComplexBase):
