@@ -4,8 +4,12 @@ from spark_auto_mapper_fhir.classproperty import genericclassproperty
 from spark_auto_mapper_fhir.extensions.extension_base import ExtensionBase
 from spark_auto_mapper_fhir.fhir_types.string import FhirString
 from spark_auto_mapper_fhir.fhir_types.uri import FhirUri
-from spark_auto_mapper_fhir.valuesets.us_core.detailed_ethnicity import DetailedEthnicity
-from spark_auto_mapper_fhir.valuesets.us_core.omb_ethnicity_category import OMBEthnicityCategory
+from spark_auto_mapper_fhir.valuesets.us_core.detailed_ethnicity import (
+    DetailedEthnicity,
+)
+from spark_auto_mapper_fhir.valuesets.us_core.omb_ethnicity_category import (
+    OMBEthnicityCategory,
+)
 
 
 class RaceItem(ExtensionBase):
@@ -13,9 +17,8 @@ class RaceItem(ExtensionBase):
     def __init__(
         self,
         url: Optional[FhirUri] = None,
-        valueCoding: Optional[Union[OMBEthnicityCategory,
-                                    DetailedEthnicity]] = None,
-        valueString: Optional[FhirString] = None
+        valueCoding: Optional[Union[OMBEthnicityCategory, DetailedEthnicity]] = None,
+        valueString: Optional[FhirString] = None,
     ) -> None:
         """
         Extension type in FHIR
@@ -23,9 +26,7 @@ class RaceItem(ExtensionBase):
         assert url in ["ombCategory", "detailed", "text"]
         assert url not in ["ombCategory", "detailed"] or valueCoding
         assert url not in ["text"] or valueString
-        super().__init__(
-            url=url, valueCoding=valueCoding, valueString=valueString
-        )
+        super().__init__(url=url, valueCoding=valueCoding, valueString=valueString)
 
     # noinspection PyMethodParameters
     @genericclassproperty
