@@ -1,6 +1,6 @@
-from typing import Optional
+from typing import Optional, Union
 
-from pyspark.sql.types import StructType
+from pyspark.sql.types import StructType, DataType
 from spark_fhir_schemas.r4.resources.careplan import CarePlanSchema
 
 from spark_auto_mapper_fhir.complex_types.meta import Meta
@@ -15,7 +15,7 @@ class CarePlan(FhirResourceBase):
         self,
         id_: FhirId,
         meta: Optional[Meta] = None,
-        extension: Optional[FhirList[ExtensionBase]] = None
+        extension: Optional[FhirList[ExtensionBase]] = None,
     ) -> None:
         """
         CarePlan Resource in FHIR
@@ -28,5 +28,7 @@ class CarePlan(FhirResourceBase):
             resourceType="CarePlan", id_=id_, meta=meta, extension=extension
         )
 
-    def get_schema(self, include_extension: bool) -> Optional[StructType]:
+    def get_schema(
+        self, include_extension: bool
+    ) -> Optional[Union[StructType, DataType]]:
         return CarePlanSchema.get_schema(include_extension=include_extension)
