@@ -1,6 +1,6 @@
-from typing import Optional
+from typing import Optional, Union
 
-from pyspark.sql.types import StructType
+from pyspark.sql.types import StructType, DataType
 from spark_fhir_schemas.r4.resources.detectedissue import DetectedIssueSchema
 
 from spark_auto_mapper_fhir.complex_types.meta import Meta
@@ -15,7 +15,7 @@ class DetectedIssue(FhirResourceBase):
         self,
         id_: FhirId,
         meta: Optional[Meta] = None,
-        extension: Optional[FhirList[ExtensionBase]] = None
+        extension: Optional[FhirList[ExtensionBase]] = None,
     ) -> None:
         """
         DetectedIssue Resource in FHIR
@@ -25,13 +25,10 @@ class DetectedIssue(FhirResourceBase):
         :param id_: id of resource
         """
         super().__init__(
-            resourceType="DetectedIssue",
-            id_=id_,
-            meta=meta,
-            extension=extension
+            resourceType="DetectedIssue", id_=id_, meta=meta, extension=extension
         )
 
-    def get_schema(self, include_extension: bool) -> Optional[StructType]:
-        return DetectedIssueSchema.get_schema(
-            include_extension=include_extension
-        )
+    def get_schema(
+        self, include_extension: bool
+    ) -> Optional[Union[StructType, DataType]]:
+        return DetectedIssueSchema.get_schema(include_extension=include_extension)
