@@ -1,6 +1,6 @@
-from typing import Optional
+from typing import Optional, Union
 
-from pyspark.sql.types import StructType
+from pyspark.sql.types import StructType, DataType
 from spark_fhir_schemas.r4.resources.device import DeviceSchema
 
 from spark_auto_mapper_fhir.complex_types.meta import Meta
@@ -15,7 +15,7 @@ class Device(FhirResourceBase):
         self,
         id_: FhirId,
         meta: Optional[Meta] = None,
-        extension: Optional[FhirList[ExtensionBase]] = None
+        extension: Optional[FhirList[ExtensionBase]] = None,
     ) -> None:
         """
         Device Resource in FHIR
@@ -24,9 +24,9 @@ class Device(FhirResourceBase):
 
         :param id_: id of resource
         """
-        super().__init__(
-            resourceType="Device", id_=id_, meta=meta, extension=extension
-        )
+        super().__init__(resourceType="Device", id_=id_, meta=meta, extension=extension)
 
-    def get_schema(self, include_extension: bool) -> Optional[StructType]:
+    def get_schema(
+        self, include_extension: bool
+    ) -> Optional[Union[StructType, DataType]]:
         return DeviceSchema.get_schema(include_extension=include_extension)
