@@ -1,5 +1,5 @@
-from typing import Optional
-from pyspark.sql.types import StructType
+from typing import Optional, Union
+from pyspark.sql.types import StructType, DataType
 from spark_fhir_schemas.r4.resources.immunization import ImmunizationSchema
 
 from spark_auto_mapper_fhir.fhir_types.id import FhirId
@@ -14,7 +14,7 @@ class Immunization(FhirResourceBase):
         self,
         id_: Optional[FhirId] = None,
         meta: Optional[Meta] = None,
-        extension: Optional[FhirList[Extension]] = None
+        extension: Optional[FhirList[Extension]] = None,
     ) -> None:
         """
         Immunization Resource in FHIR
@@ -24,13 +24,10 @@ class Immunization(FhirResourceBase):
         :param id_: id of resource
         """
         super().__init__(
-            resourceType="Immunization",
-            id_=id_,
-            meta=meta,
-            extension=extension
+            resourceType="Immunization", id_=id_, meta=meta, extension=extension
         )
 
-    def get_schema(self, include_extension: bool) -> Optional[StructType]:
-        return ImmunizationSchema.get_schema(
-            include_extension=include_extension
-        )
+    def get_schema(
+        self, include_extension: bool
+    ) -> Optional[Union[StructType, DataType]]:
+        return ImmunizationSchema.get_schema(include_extension=include_extension)
