@@ -1,5 +1,5 @@
-from typing import Optional
-from pyspark.sql.types import StructType
+from typing import Optional, Union
+from pyspark.sql.types import StructType, DataType
 from spark_fhir_schemas.r4.resources.media import MediaSchema
 
 from spark_auto_mapper_fhir.fhir_types.id import FhirId
@@ -14,7 +14,7 @@ class Media(FhirResourceBase):
         self,
         id_: Optional[FhirId] = None,
         meta: Optional[Meta] = None,
-        extension: Optional[FhirList[Extension]] = None
+        extension: Optional[FhirList[Extension]] = None,
     ) -> None:
         """
         Media Resource in FHIR
@@ -23,9 +23,9 @@ class Media(FhirResourceBase):
 
         :param id_: id of resource
         """
-        super().__init__(
-            resourceType="Media", id_=id_, meta=meta, extension=extension
-        )
+        super().__init__(resourceType="Media", id_=id_, meta=meta, extension=extension)
 
-    def get_schema(self, include_extension: bool) -> Optional[StructType]:
+    def get_schema(
+        self, include_extension: bool
+    ) -> Optional[Union[StructType, DataType]]:
         return MediaSchema.get_schema(include_extension=include_extension)
