@@ -1,5 +1,5 @@
-from typing import Optional
-from pyspark.sql.types import StructType
+from typing import Optional, Union
+from pyspark.sql.types import StructType, DataType
 from spark_fhir_schemas.r4.resources.questionnaire import QuestionnaireSchema
 
 from spark_auto_mapper_fhir.fhir_types.id import FhirId
@@ -14,7 +14,7 @@ class Questionnaire(FhirResourceBase):
         self,
         id_: Optional[FhirId] = None,
         meta: Optional[Meta] = None,
-        extension: Optional[FhirList[Extension]] = None
+        extension: Optional[FhirList[Extension]] = None,
     ) -> None:
         """
         Questionnaire Resource in FHIR
@@ -26,13 +26,10 @@ class Questionnaire(FhirResourceBase):
         """
         # TODO fill in all the properties
         super().__init__(
-            resourceType="Questionnaire",
-            id_=id_,
-            meta=meta,
-            extension=extension
+            resourceType="Questionnaire", id_=id_, meta=meta, extension=extension
         )
 
-    def get_schema(self, include_extension: bool) -> Optional[StructType]:
-        return QuestionnaireSchema.get_schema(
-            include_extension=include_extension
-        )
+    def get_schema(
+        self, include_extension: bool
+    ) -> Optional[Union[StructType, DataType]]:
+        return QuestionnaireSchema.get_schema(include_extension=include_extension)
