@@ -1,5 +1,5 @@
-from typing import Optional
-from pyspark.sql.types import StructType
+from typing import Optional, Union
+from pyspark.sql.types import StructType, DataType
 from spark_fhir_schemas.r4.resources.specimen import SpecimenSchema
 
 from spark_auto_mapper_fhir.fhir_types.id import FhirId
@@ -14,7 +14,7 @@ class Specimen(FhirResourceBase):
         self,
         id_: Optional[FhirId] = None,
         meta: Optional[Meta] = None,
-        extension: Optional[FhirList[Extension]] = None
+        extension: Optional[FhirList[Extension]] = None,
     ) -> None:
         """
         Specimen Resource in FHIR
@@ -27,5 +27,7 @@ class Specimen(FhirResourceBase):
             resourceType="Specimen", id_=id_, meta=meta, extension=extension
         )
 
-    def get_schema(self, include_extension: bool) -> Optional[StructType]:
+    def get_schema(
+        self, include_extension: bool
+    ) -> Optional[Union[StructType, DataType]]:
         return SpecimenSchema.get_schema(include_extension=include_extension)
