@@ -13,21 +13,22 @@ class ClaimExceptionCode(FhirValueSetBase):
     """
     https://hl7.org/FHIR/valueset-claim-exception.html
     """
+
     def __init__(self, value: AutoMapperTextInputType):
         super().__init__(value=value)
 
     # noinspection PyPep8Naming,SpellCheckingInspection
     class classproperty(object):
-        def __init__(self, f: Callable[..., 'ClaimExceptionCode']) -> None:
-            self.f: Callable[..., 'ClaimExceptionCode'] = f
+        def __init__(self, f: Callable[..., "ClaimExceptionCode"]) -> None:
+            self.f: Callable[..., "ClaimExceptionCode"] = f
 
         def __get__(
-            self, obj: Any, owner: Type['ClaimExceptionCode']
-        ) -> 'ClaimExceptionCode':
+            self, obj: Any, owner: Type["ClaimExceptionCode"]
+        ) -> "ClaimExceptionCode":
             return self.f(owner)
 
     @classproperty
-    def NameOfYourFirstValue(cls) -> 'ClaimExceptionCode':
+    def NameOfYourFirstValue(cls) -> "ClaimExceptionCode":
         """
         Comment
         """
