@@ -13,26 +13,39 @@ class ClaimUseCode(FhirValueSetBase):
     """
     https://hl7.org/FHIR/valueset-claim-use.html
     """
+
     def __init__(self, value: AutoMapperTextInputType):
         super().__init__(value=value)
 
     # noinspection PyPep8Naming,SpellCheckingInspection
     class classproperty(object):
-        def __init__(self, f: Callable[..., 'ClaimUseCode']) -> None:
-            self.f: Callable[..., 'ClaimUseCode'] = f
+        def __init__(self, f: Callable[..., "ClaimUseCode"]) -> None:
+            self.f: Callable[..., "ClaimUseCode"] = f
 
-        def __get__(
-            self, obj: Any, owner: Type['ClaimUseCode']
-        ) -> 'ClaimUseCode':
+        def __get__(self, obj: Any, owner: Type["ClaimUseCode"]) -> "ClaimUseCode":
             return self.f(owner)
 
     @classproperty
-    def NameOfYourFirstValue(cls) -> 'ClaimUseCode':
+    def Claim(cls) -> "ClaimUseCode":
         """
-        Comment
+        The treatment is complete and this represents a Claim for the services.
         """
         # noinspection PyCallingNonCallable
-        return ClaimUseCode("A")
+        return ClaimUseCode("claim")
+
+    def Preauthorization(cls) -> "ClaimUseCode":
+        """
+        The treatment is proposed and this represents a Pre-authorization for the services.
+        """
+        # noinspection PyCallingNonCallable
+        return ClaimUseCode("preauthorization")
+
+    def Predetermination(cls) -> "ClaimUseCode":
+        """
+        The treatment is proposed and this represents a Pre-determination for the services.
+        """
+        # noinspection PyCallingNonCallable
+        return ClaimUseCode("predetermination")
 
     @genericclassproperty
     def codeset(cls) -> FhirUri:
