@@ -13,21 +13,22 @@ class ContactPointUseCode(FhirValueSetBase):
     """
     https://hl7.org/FHIR/valueset-contact-point-use.html
     """
+
     def __init__(self, value: AutoMapperTextInputType):
         super().__init__(value=value)
 
     # noinspection PyPep8Naming,SpellCheckingInspection
     class classproperty(object):
-        def __init__(self, f: Callable[..., 'ContactPointUseCode']) -> None:
-            self.f: Callable[..., 'ContactPointUseCode'] = f
+        def __init__(self, f: Callable[..., "ContactPointUseCode"]) -> None:
+            self.f: Callable[..., "ContactPointUseCode"] = f
 
         def __get__(
-            self, obj: Any, owner: Type['ContactPointUseCode']
-        ) -> 'ContactPointUseCode':
+            self, obj: Any, owner: Type["ContactPointUseCode"]
+        ) -> "ContactPointUseCode":
             return self.f(owner)
 
     @classproperty
-    def NameOfYourFirstValue(cls) -> 'ContactPointUseCode':
+    def NameOfYourFirstValue(cls) -> "ContactPointUseCode":
         """
         Comment
         """
