@@ -13,21 +13,22 @@ class CoverageClassCode(FhirValueSetBase):
     """
     https://hl7.org/FHIR/valueset-coverage-class.html
     """
+
     def __init__(self, value: AutoMapperTextInputType):
         super().__init__(value=value)
 
     # noinspection PyPep8Naming,SpellCheckingInspection
     class classproperty(object):
-        def __init__(self, f: Callable[..., 'CoverageClassCode']) -> None:
-            self.f: Callable[..., 'CoverageClassCode'] = f
+        def __init__(self, f: Callable[..., "CoverageClassCode"]) -> None:
+            self.f: Callable[..., "CoverageClassCode"] = f
 
         def __get__(
-            self, obj: Any, owner: Type['CoverageClassCode']
-        ) -> 'CoverageClassCode':
+            self, obj: Any, owner: Type["CoverageClassCode"]
+        ) -> "CoverageClassCode":
             return self.f(owner)
 
     @classproperty
-    def NameOfYourFirstValue(cls) -> 'CoverageClassCode':
+    def NameOfYourFirstValue(cls) -> "CoverageClassCode":
         """
         Comment
         """
