@@ -13,23 +13,22 @@ class CoverageFinancialExceptionCode(FhirValueSetBase):
     """
     https://hl7.org/FHIR/valueset-coverage-financial-exception.html
     """
+
     def __init__(self, value: AutoMapperTextInputType):
         super().__init__(value=value)
 
     # noinspection PyPep8Naming,SpellCheckingInspection
     class classproperty(object):
-        def __init__(
-            self, f: Callable[..., 'CoverageFinancialExceptionCode']
-        ) -> None:
-            self.f: Callable[..., 'CoverageFinancialExceptionCode'] = f
+        def __init__(self, f: Callable[..., "CoverageFinancialExceptionCode"]) -> None:
+            self.f: Callable[..., "CoverageFinancialExceptionCode"] = f
 
         def __get__(
-            self, obj: Any, owner: Type['CoverageFinancialExceptionCode']
-        ) -> 'CoverageFinancialExceptionCode':
+            self, obj: Any, owner: Type["CoverageFinancialExceptionCode"]
+        ) -> "CoverageFinancialExceptionCode":
             return self.f(owner)
 
     @classproperty
-    def NameOfYourFirstValue(cls) -> 'CoverageFinancialExceptionCode':
+    def NameOfYourFirstValue(cls) -> "CoverageFinancialExceptionCode":
         """
         Comment
         """
