@@ -13,21 +13,20 @@ class CurrencyCode(FhirValueSetBase):
     """
     https://hl7.org/FHIR/valueset-currencies.html
     """
+
     def __init__(self, value: AutoMapperTextInputType):
         super().__init__(value=value)
 
     # noinspection PyPep8Naming,SpellCheckingInspection
     class classproperty(object):
-        def __init__(self, f: Callable[..., 'CurrencyCode']) -> None:
-            self.f: Callable[..., 'CurrencyCode'] = f
+        def __init__(self, f: Callable[..., "CurrencyCode"]) -> None:
+            self.f: Callable[..., "CurrencyCode"] = f
 
-        def __get__(
-            self, obj: Any, owner: Type['CurrencyCode']
-        ) -> 'CurrencyCode':
+        def __get__(self, obj: Any, owner: Type["CurrencyCode"]) -> "CurrencyCode":
             return self.f(owner)
 
     @classproperty
-    def NameOfYourFirstValue(cls) -> 'CurrencyCode':
+    def NameOfYourFirstValue(cls) -> "CurrencyCode":
         """
         Comment
         """
