@@ -13,23 +13,22 @@ class DiagnosisOnAdmissionCode(FhirValueSetBase):
     """
     https://hl7.org/FHIR/valueset-ex-diagnosis-on-admission.html
     """
+
     def __init__(self, value: AutoMapperTextInputType):
         super().__init__(value=value)
 
     # noinspection PyPep8Naming,SpellCheckingInspection
     class classproperty(object):
-        def __init__(
-            self, f: Callable[..., 'DiagnosisOnAdmissionCode']
-        ) -> None:
-            self.f: Callable[..., 'DiagnosisOnAdmissionCode'] = f
+        def __init__(self, f: Callable[..., "DiagnosisOnAdmissionCode"]) -> None:
+            self.f: Callable[..., "DiagnosisOnAdmissionCode"] = f
 
         def __get__(
-            self, obj: Any, owner: Type['DiagnosisOnAdmissionCode']
-        ) -> 'DiagnosisOnAdmissionCode':
+            self, obj: Any, owner: Type["DiagnosisOnAdmissionCode"]
+        ) -> "DiagnosisOnAdmissionCode":
             return self.f(owner)
 
     @classproperty
-    def NameOfYourFirstValue(cls) -> 'DiagnosisOnAdmissionCode':
+    def NameOfYourFirstValue(cls) -> "DiagnosisOnAdmissionCode":
         """
         Comment
         """
