@@ -13,28 +13,28 @@ class IdentifierTypeCode(FhirValueSetBase):
     """
     https://hl7.org/FHIR/valueset-identifier-type.html
     """
+
     def __init__(self, value: AutoMapperTextInputType):
         super().__init__(value=value)
 
     # noinspection PyPep8Naming,SpellCheckingInspection
     class classproperty(object):
-        def __init__(self, f: Callable[..., 'IdentifierTypeCode']) -> None:
-            self.f: Callable[..., 'IdentifierTypeCode'] = f
+        def __init__(self, f: Callable[..., "IdentifierTypeCode"]) -> None:
+            self.f: Callable[..., "IdentifierTypeCode"] = f
 
         def __get__(
-            self, obj: Any, owner: Type['IdentifierTypeCode']
-        ) -> 'IdentifierTypeCode':
+            self, obj: Any, owner: Type["IdentifierTypeCode"]
+        ) -> "IdentifierTypeCode":
             return self.f(owner)
 
     @classproperty
-    def AccreditationCertificationIdentifier(cls) -> 'IdentifierTypeCode':
-        """
-        """
+    def AccreditationCertificationIdentifier(cls) -> "IdentifierTypeCode":
+        """ """
         # noinspection PyCallingNonCallable
         return IdentifierTypeCode("AC")
 
     @classproperty
-    def AmericanMedicalAssociationNumber(cls) -> 'IdentifierTypeCode':
+    def AmericanMedicalAssociationNumber(cls) -> "IdentifierTypeCode":
         """
         A physician identifier assigned by the AMA.
         """
@@ -42,7 +42,7 @@ class IdentifierTypeCode(FhirValueSetBase):
         return IdentifierTypeCode("AMA")
 
     @classproperty
-    def AccountNumber(cls) -> 'IdentifierTypeCode':
+    def AccountNumber(cls) -> "IdentifierTypeCode":
         """
         An identifier that is unique to an account.
         """
@@ -50,7 +50,7 @@ class IdentifierTypeCode(FhirValueSetBase):
         return IdentifierTypeCode("AN")
 
     @classproperty
-    def AccountNumberCreditor(cls) -> 'IdentifierTypeCode':
+    def AccountNumberCreditor(cls) -> "IdentifierTypeCode":
         """
         Class: Financial
         A more precise definition of an account number: sometimes two distinct account numbers must be transmitted
@@ -61,7 +61,7 @@ class IdentifierTypeCode(FhirValueSetBase):
 
     # noinspection SpellCheckingInspection
     @classproperty
-    def AccountNumberDebitor(cls) -> 'IdentifierTypeCode':
+    def AccountNumberDebitor(cls) -> "IdentifierTypeCode":
         """
         Class: Financial
         A more precise definition of an account number: sometimes two distinct account numbers must be
@@ -71,14 +71,13 @@ class IdentifierTypeCode(FhirValueSetBase):
         return IdentifierTypeCode("AND")
 
     @classproperty
-    def AnonymousIdentifier(cls) -> 'IdentifierTypeCode':
-        """
-        """
+    def AnonymousIdentifier(cls) -> "IdentifierTypeCode":
+        """ """
         # noinspection PyCallingNonCallable
         return IdentifierTypeCode("ANON")
 
     @classproperty
-    def TemporaryAccountNumber(cls) -> 'IdentifierTypeCode':
+    def TemporaryAccountNumber(cls) -> "IdentifierTypeCode":
         """
         Class: Financial
         Temporary version of an Account Number.
@@ -90,14 +89,13 @@ class IdentifierTypeCode(FhirValueSetBase):
         return IdentifierTypeCode("ANT")
 
     @classproperty
-    def BankAccountNumber(cls) -> 'IdentifierTypeCode':
-        """
-        """
+    def BankAccountNumber(cls) -> "IdentifierTypeCode":
+        """ """
         # noinspection PyCallingNonCallable
         return IdentifierTypeCode("BA")
 
     @classproperty
-    def BankCardNumber(cls) -> 'IdentifierTypeCode':
+    def BankCardNumber(cls) -> "IdentifierTypeCode":
         """
         Class: Financial
         An identifier that is unique to a person's bank card.
@@ -106,14 +104,13 @@ class IdentifierTypeCode(FhirValueSetBase):
         return IdentifierTypeCode("BC")
 
     @classproperty
-    def BirthCertificateFileNumber(cls) -> 'IdentifierTypeCode':
-        """
-        """
+    def BirthCertificateFileNumber(cls) -> "IdentifierTypeCode":
+        """ """
         # noinspection PyCallingNonCallable
         return IdentifierTypeCode("BCFN")
 
     @classproperty
-    def BirthCertificate(cls) -> 'IdentifierTypeCode':
+    def BirthCertificate(cls) -> "IdentifierTypeCode":
         """
         A number associated with a document identifying the event of a person's birth.
         """
@@ -121,7 +118,7 @@ class IdentifierTypeCode(FhirValueSetBase):
         return IdentifierTypeCode("BCT")
 
     @classproperty
-    def BirthRegistryNumber(cls) -> 'IdentifierTypeCode':
+    def BirthRegistryNumber(cls) -> "IdentifierTypeCode":
         """
         An identifier unique within the Assigning Authority that is the official legal record of a person's birth.
         """
@@ -129,7 +126,7 @@ class IdentifierTypeCode(FhirValueSetBase):
         return IdentifierTypeCode("BR")
 
     @classproperty
-    def CostCenterNumber(cls) -> 'IdentifierTypeCode':
+    def CostCenterNumber(cls) -> "IdentifierTypeCode":
         """
         Class: Financial
         Use Case: needed especially for transmitting information about invoices.
@@ -138,7 +135,7 @@ class IdentifierTypeCode(FhirValueSetBase):
         return IdentifierTypeCode("CC")
 
     @classproperty
-    def ChangeOfNameDocument(cls) -> 'IdentifierTypeCode':
+    def ChangeOfNameDocument(cls) -> "IdentifierTypeCode":
         """
         A number associated with a document identifying a person's legal change of name.
         """
@@ -146,14 +143,13 @@ class IdentifierTypeCode(FhirValueSetBase):
         return IdentifierTypeCode("CONM")
 
     @classproperty
-    def CountyNumber(cls) -> 'IdentifierTypeCode':
-        """
-        """
+    def CountyNumber(cls) -> "IdentifierTypeCode":
+        """ """
         # noinspection PyCallingNonCallable
         return IdentifierTypeCode("CY")
 
     @classproperty
-    def CitizenshipCard(cls) -> 'IdentifierTypeCode':
+    def CitizenshipCard(cls) -> "IdentifierTypeCode":
         """
         A number assigned by a person's country of residence to identify a person's citizenship.
         """
@@ -161,21 +157,19 @@ class IdentifierTypeCode(FhirValueSetBase):
         return IdentifierTypeCode("CZ")
 
     @classproperty
-    def DeathCertificateId(cls) -> 'IdentifierTypeCode':
-        """
-        """
+    def DeathCertificateId(cls) -> "IdentifierTypeCode":
+        """ """
         # noinspection PyCallingNonCallable
         return IdentifierTypeCode("DC")
 
     @classproperty
-    def DeathCertificateFileNumber(cls) -> 'IdentifierTypeCode':
-        """
-        """
+    def DeathCertificateFileNumber(cls) -> "IdentifierTypeCode":
+        """ """
         # noinspection PyCallingNonCallable
         return IdentifierTypeCode("DCFN")
 
     @classproperty
-    def DentistLicenseNumber(cls) -> 'IdentifierTypeCode':
+    def DentistLicenseNumber(cls) -> "IdentifierTypeCode":
         """
         An identifier that is unique to a dentist within the jurisdiction of the licensing board
         """
@@ -183,9 +177,7 @@ class IdentifierTypeCode(FhirValueSetBase):
         return IdentifierTypeCode("DDS")
 
     @classproperty
-    def DrugEnforcementAdministrationRegistrationNumber(
-        cls
-    ) -> 'IdentifierTypeCode':
+    def DrugEnforcementAdministrationRegistrationNumber(cls) -> "IdentifierTypeCode":
         """
         An identifier for an individual or organization relative to controlled substance regulation and transactions.
         Use case: This is a registration number that identifies an individual or organization relative to
@@ -200,30 +192,25 @@ class IdentifierTypeCode(FhirValueSetBase):
         return IdentifierTypeCode("DEA")
 
     @classproperty
-    def DrugFurnishingOrPrescriptiveAuthorityNumber(
-        cls
-    ) -> 'IdentifierTypeCode':
-        """
-        """
+    def DrugFurnishingOrPrescriptiveAuthorityNumber(cls) -> "IdentifierTypeCode":
+        """ """
         # noinspection PyCallingNonCallable
         return IdentifierTypeCode("DFN")
 
     @classproperty
-    def DriverLicenseNumber(cls) -> 'IdentifierTypeCode':
-        """
-        """
+    def DriverLicenseNumber(cls) -> "IdentifierTypeCode":
+        """ """
         # noinspection PyCallingNonCallable
         return IdentifierTypeCode("DL")
 
     @classproperty
-    def DoctorNumber(cls) -> 'IdentifierTypeCode':
-        """
-        """
+    def DoctorNumber(cls) -> "IdentifierTypeCode":
+        """ """
         # noinspection PyCallingNonCallable
         return IdentifierTypeCode("DN")
 
     @classproperty
-    def OsteopathicLicenseNumber(cls) -> 'IdentifierTypeCode':
+    def OsteopathicLicenseNumber(cls) -> "IdentifierTypeCode":
         """
         An identifier that is unique to an osteopath within the jurisdiction of a licensing board.
         """
@@ -231,7 +218,7 @@ class IdentifierTypeCode(FhirValueSetBase):
         return IdentifierTypeCode("DO")
 
     @classproperty
-    def PodiatristLicenseNumber(cls) -> 'IdentifierTypeCode':
+    def PodiatristLicenseNumber(cls) -> "IdentifierTypeCode":
         """
         An identifier that is unique to a podiatrist within the jurisdiction of the licensing board.
         """
@@ -239,7 +226,7 @@ class IdentifierTypeCode(FhirValueSetBase):
         return IdentifierTypeCode("DPM")
 
     @classproperty
-    def EmployeeId(cls) -> 'IdentifierTypeCode':
+    def EmployeeId(cls) -> "IdentifierTypeCode":
         """
         A number that uniquely identifies an employee to an employer.
         """
@@ -247,14 +234,13 @@ class IdentifierTypeCode(FhirValueSetBase):
         return IdentifierTypeCode("EI")
 
     @classproperty
-    def EmployerNumber(cls) -> 'IdentifierTypeCode':
-        """
-        """
+    def EmployerNumber(cls) -> "IdentifierTypeCode":
+        """ """
         # noinspection PyCallingNonCallable
         return IdentifierTypeCode("EN")
 
     @classproperty
-    def StaffEnterpriseNumber(cls) -> 'IdentifierTypeCode':
+    def StaffEnterpriseNumber(cls) -> "IdentifierTypeCode":
         """
         An identifier that is unique to a staff member within an enterprise (as identified by the Assigning Authority).
         """
@@ -262,14 +248,13 @@ class IdentifierTypeCode(FhirValueSetBase):
         return IdentifierTypeCode("ESN")
 
     @classproperty
-    def FacilityId(cls) -> 'IdentifierTypeCode':
-        """
-        """
+    def FacilityId(cls) -> "IdentifierTypeCode":
+        """ """
         # noinspection PyCallingNonCallable
         return IdentifierTypeCode("FI")
 
     @classproperty
-    def GuarantorInternalIdentifier(cls) -> 'IdentifierTypeCode':
+    def GuarantorInternalIdentifier(cls) -> "IdentifierTypeCode":
         """
         Class: Financial
         """
@@ -277,7 +262,7 @@ class IdentifierTypeCode(FhirValueSetBase):
         return IdentifierTypeCode("GI")
 
     @classproperty
-    def GeneralLedgerNumber(cls) -> 'IdentifierTypeCode':
+    def GeneralLedgerNumber(cls) -> "IdentifierTypeCode":
         """
         Class: Financial
         """
@@ -285,7 +270,7 @@ class IdentifierTypeCode(FhirValueSetBase):
         return IdentifierTypeCode("GL")
 
     @classproperty
-    def GuarantorExternalIdentifier(cls) -> 'IdentifierTypeCode':
+    def GuarantorExternalIdentifier(cls) -> "IdentifierTypeCode":
         """
         Class: Financial
         """
@@ -293,21 +278,19 @@ class IdentifierTypeCode(FhirValueSetBase):
         return IdentifierTypeCode("GN")
 
     @classproperty
-    def HealthCardNumber(cls) -> 'IdentifierTypeCode':
-        """
-        """
+    def HealthCardNumber(cls) -> "IdentifierTypeCode":
+        """ """
         # noinspection PyCallingNonCallable
         return IdentifierTypeCode("HC")
 
     @classproperty
-    def LicenseNumber(cls) -> 'IdentifierTypeCode':
-        """
-        """
+    def LicenseNumber(cls) -> "IdentifierTypeCode":
+        """ """
         # noinspection PyCallingNonCallable
         return IdentifierTypeCode("LN")
 
     @classproperty
-    def PatientMedicaidNumber(cls) -> 'IdentifierTypeCode':
+    def PatientMedicaidNumber(cls) -> "IdentifierTypeCode":
         """
         Class: Insurance
         """
@@ -315,7 +298,7 @@ class IdentifierTypeCode(FhirValueSetBase):
         return IdentifierTypeCode("MA")
 
     @classproperty
-    def MemberNumber(cls) -> 'IdentifierTypeCode':
+    def MemberNumber(cls) -> "IdentifierTypeCode":
         """
         An identifier for the insured of an insurance policy (this insured always has a subscriber),
         usually assigned by the insurance carrier. Use Case: Person is covered by an insurance policy.
@@ -325,7 +308,7 @@ class IdentifierTypeCode(FhirValueSetBase):
         return IdentifierTypeCode("MB")
 
     @classproperty
-    def PatientMedicareNumber(cls) -> 'IdentifierTypeCode':
+    def PatientMedicareNumber(cls) -> "IdentifierTypeCode":
         """
         Patient's Medicare number. Class: Insurance
         """
@@ -333,7 +316,7 @@ class IdentifierTypeCode(FhirValueSetBase):
         return IdentifierTypeCode("MC")
 
     @classproperty
-    def PractitionerMedicaidNumber(cls) -> 'IdentifierTypeCode':
+    def PractitionerMedicaidNumber(cls) -> "IdentifierTypeCode":
         """
         Practitioner Medicaid number. Class: Insurance
         """
@@ -341,7 +324,7 @@ class IdentifierTypeCode(FhirValueSetBase):
         return IdentifierTypeCode("MCD")
 
     @classproperty
-    def PractitionerMedicareNumber(cls) -> 'IdentifierTypeCode':
+    def PractitionerMedicareNumber(cls) -> "IdentifierTypeCode":
         """
         Practitioner Medicare number. Class: Insurance
         """
@@ -349,7 +332,7 @@ class IdentifierTypeCode(FhirValueSetBase):
         return IdentifierTypeCode("MCR")
 
     @classproperty
-    def MedicalLicenseNumber(cls) -> 'IdentifierTypeCode':
+    def MedicalLicenseNumber(cls) -> "IdentifierTypeCode":
         """
         An identifier that is unique to a medical doctor within the jurisdiction of a licensing board.
         Use Case: These license numbers are sometimes used as identifiers. In some states,
@@ -363,7 +346,7 @@ class IdentifierTypeCode(FhirValueSetBase):
         return IdentifierTypeCode("MD")
 
     @classproperty
-    def MilitaryIdNumber(cls) -> 'IdentifierTypeCode':
+    def MilitaryIdNumber(cls) -> "IdentifierTypeCode":
         """
         A number assigned to an individual who has had military duty, but is not currently on active duty.
         The number is assigned by the DOD or Veterans' Affairs (VA).
@@ -372,7 +355,7 @@ class IdentifierTypeCode(FhirValueSetBase):
         return IdentifierTypeCode("MI")
 
     @classproperty
-    def MedicalRecordNumber(cls) -> 'IdentifierTypeCode':
+    def MedicalRecordNumber(cls) -> "IdentifierTypeCode":
         """
         An identifier that is unique to a patient within a set of medical records,
         not necessarily unique within an application.
@@ -381,7 +364,7 @@ class IdentifierTypeCode(FhirValueSetBase):
         return IdentifierTypeCode("MR")
 
     @classproperty
-    def TemporaryMedicalRecordNumber(cls) -> 'IdentifierTypeCode':
+    def TemporaryMedicalRecordNumber(cls) -> "IdentifierTypeCode":
         """
         Temporary version of a Medical Record Number
         Use Case: An ancillary system that does not normally assign medical record numbers
@@ -392,7 +375,7 @@ class IdentifierTypeCode(FhirValueSetBase):
         return IdentifierTypeCode("MRT")
 
     @classproperty
-    def NaturalizationCertificate(cls) -> 'IdentifierTypeCode':
+    def NaturalizationCertificate(cls) -> "IdentifierTypeCode":
         """
         A number associated with a document identifying a person's retention of citizenship in a particular country.
         """
@@ -400,7 +383,7 @@ class IdentifierTypeCode(FhirValueSetBase):
         return IdentifierTypeCode("NCT")
 
     @classproperty
-    def NationalEmployerIdentifier(cls) -> 'IdentifierTypeCode':
+    def NationalEmployerIdentifier(cls) -> "IdentifierTypeCode":
         """
         In the US, the Assigning Authority for this value is typically CMS, but it may be used by all providers
          and insurance companies in HIPAA related transactions.
@@ -409,7 +392,7 @@ class IdentifierTypeCode(FhirValueSetBase):
         return IdentifierTypeCode("NE")
 
     @classproperty
-    def NationalHealthPlanIdentifier(cls) -> 'IdentifierTypeCode':
+    def NationalHealthPlanIdentifier(cls) -> "IdentifierTypeCode":
         """
         Class: Insurance
         Used for the UK NHS national identifier.
@@ -420,7 +403,7 @@ class IdentifierTypeCode(FhirValueSetBase):
         return IdentifierTypeCode("NH")
 
     @classproperty
-    def NationalUniqueIndividualIdentifier(cls) -> 'IdentifierTypeCode':
+    def NationalUniqueIndividualIdentifier(cls) -> "IdentifierTypeCode":
         """
         An identifier that is unique to a nurse practitioner within the jurisdiction of a certifying board.
         """
@@ -428,7 +411,7 @@ class IdentifierTypeCode(FhirValueSetBase):
         return IdentifierTypeCode("NI")
 
     @classproperty
-    def NursePractitionerNumber(cls) -> 'IdentifierTypeCode':
+    def NursePractitionerNumber(cls) -> "IdentifierTypeCode":
         """
         An identifier that is unique to a nurse practitioner within the jurisdiction of a certifying board.
         """
@@ -436,7 +419,7 @@ class IdentifierTypeCode(FhirValueSetBase):
         return IdentifierTypeCode("NP")
 
     @classproperty
-    def NationalProviderIdentifier(cls) -> 'IdentifierTypeCode':
+    def NationalProviderIdentifier(cls) -> "IdentifierTypeCode":
         """
         Class: Insurance In the US, the Assigning Authority for this value is typically CMS,
         but it may be used by all providers and insurance companies in HIPAA related transactions.
@@ -445,7 +428,7 @@ class IdentifierTypeCode(FhirValueSetBase):
         return IdentifierTypeCode("NPI")
 
     @classproperty
-    def OptometristLicenseNumber(cls) -> 'IdentifierTypeCode':
+    def OptometristLicenseNumber(cls) -> "IdentifierTypeCode":
         """
         A number that is unique to an individual optometrist within the jurisdiction of the licensing board.
         """
@@ -453,7 +436,7 @@ class IdentifierTypeCode(FhirValueSetBase):
         return IdentifierTypeCode("OD")
 
     @classproperty
-    def PhysicianAssistantNumber(cls) -> 'IdentifierTypeCode':
+    def PhysicianAssistantNumber(cls) -> "IdentifierTypeCode":
         """
         An identifier that is unique to a physician assistant within the jurisdiction of a licensing board
         """
@@ -461,14 +444,13 @@ class IdentifierTypeCode(FhirValueSetBase):
         return IdentifierTypeCode("PA")
 
     @classproperty
-    def PensionNumber(cls) -> 'IdentifierTypeCode':
-        """
-        """
+    def PensionNumber(cls) -> "IdentifierTypeCode":
+        """ """
         # noinspection PyCallingNonCallable
         return IdentifierTypeCode("PEN")
 
     @classproperty
-    def PatientInternalIdentifier(cls) -> 'IdentifierTypeCode':
+    def PatientInternalIdentifier(cls) -> "IdentifierTypeCode":
         """
         A number that is unique to a patient within an Assigning Authority.
         """
@@ -476,7 +458,7 @@ class IdentifierTypeCode(FhirValueSetBase):
         return IdentifierTypeCode("PI")
 
     @classproperty
-    def PersonNumber(cls) -> 'IdentifierTypeCode':
+    def PersonNumber(cls) -> "IdentifierTypeCode":
         """
         A number that is unique to a living subject within an Assigning Authority.
         """
@@ -484,7 +466,7 @@ class IdentifierTypeCode(FhirValueSetBase):
         return IdentifierTypeCode("PN")
 
     @classproperty
-    def PassportNumber(cls) -> 'IdentifierTypeCode':
+    def PassportNumber(cls) -> "IdentifierTypeCode":
         """
         A unique number assigned to the document affirming that a person is a citizen of the country.
         In the US this number is issued only by the State Department.
@@ -493,21 +475,19 @@ class IdentifierTypeCode(FhirValueSetBase):
         return IdentifierTypeCode("PPN")
 
     @classproperty
-    def ProviderNumber(cls) -> 'IdentifierTypeCode':
-        """
-        """
+    def ProviderNumber(cls) -> "IdentifierTypeCode":
+        """ """
         # noinspection PyCallingNonCallable
         return IdentifierTypeCode("PRN")
 
     @classproperty
-    def PatientExternalIdentifier(cls) -> 'IdentifierTypeCode':
-        """
-        """
+    def PatientExternalIdentifier(cls) -> "IdentifierTypeCode":
+        """ """
         # noinspection PyCallingNonCallable
         return IdentifierTypeCode("PT")
 
     @classproperty
-    def ResourceIdentifier(cls) -> 'IdentifierTypeCode':
+    def ResourceIdentifier(cls) -> "IdentifierTypeCode":
         """
         A generalized resource identifier. Use Case: An identifier type is needed to accommodate
         what are commonly known as resources. The resources can include human (e.g. a respiratory therapist),
@@ -518,14 +498,13 @@ class IdentifierTypeCode(FhirValueSetBase):
         return IdentifierTypeCode("RI")
 
     @classproperty
-    def SocialBeneficiaryIdentifier(cls) -> 'IdentifierTypeCode':
-        """
-        """
+    def SocialBeneficiaryIdentifier(cls) -> "IdentifierTypeCode":
+        """ """
         # noinspection PyCallingNonCallable
         return IdentifierTypeCode("SB")
 
     @classproperty
-    def SpecimenId(cls) -> 'IdentifierTypeCode':
+    def SpecimenId(cls) -> "IdentifierTypeCode":
         """
         Identifier for a specimen. Used when it is not known if the specimen ID is a unique specimen ID (USID)
         or an ancestor ID (ASID).
@@ -534,14 +513,13 @@ class IdentifierTypeCode(FhirValueSetBase):
         return IdentifierTypeCode("SID")
 
     @classproperty
-    def StateLicense(cls) -> 'IdentifierTypeCode':
-        """
-        """
+    def StateLicense(cls) -> "IdentifierTypeCode":
+        """ """
         # noinspection PyCallingNonCallable
         return IdentifierTypeCode("SL")
 
     @classproperty
-    def SubscriberNumber(cls) -> 'IdentifierTypeCode':
+    def SubscriberNumber(cls) -> "IdentifierTypeCode":
         """
         Class: Insurance An identifier for a subscriber of an insurance policy which is unique for,
         and usually assigned by, the insurance carrier.
@@ -552,21 +530,19 @@ class IdentifierTypeCode(FhirValueSetBase):
         return IdentifierTypeCode("SN")
 
     @classproperty
-    def SerialNumber(cls) -> 'IdentifierTypeCode':
-        """
-        """
+    def SerialNumber(cls) -> "IdentifierTypeCode":
+        """ """
         # noinspection PyCallingNonCallable
         return IdentifierTypeCode("SNO")
 
     @classproperty
-    def StateRegistryId(cls) -> 'IdentifierTypeCode':
-        """
-        """
+    def StateRegistryId(cls) -> "IdentifierTypeCode":
+        """ """
         # noinspection PyCallingNonCallable
         return IdentifierTypeCode("SR")
 
     @classproperty
-    def SocialSecurityNumber(cls) -> 'IdentifierTypeCode':
+    def SocialSecurityNumber(cls) -> "IdentifierTypeCode":
         """
         Social Security number
         """
@@ -574,42 +550,37 @@ class IdentifierTypeCode(FhirValueSetBase):
         return IdentifierTypeCode("SS")
 
     @classproperty
-    def ShipmentTrackingNumber(cls) -> 'IdentifierTypeCode':
-        """
-        """
+    def ShipmentTrackingNumber(cls) -> "IdentifierTypeCode":
+        """ """
         # noinspection PyCallingNonCallable
         return IdentifierTypeCode("STN")
 
     @classproperty
-    def TaxIdNumber(cls) -> 'IdentifierTypeCode':
-        """
-        """
+    def TaxIdNumber(cls) -> "IdentifierTypeCode":
+        """ """
         # noinspection PyCallingNonCallable
         return IdentifierTypeCode("TAX")
 
     @classproperty
-    def TrainingLicenseNumber(cls) -> 'IdentifierTypeCode':
-        """
-        """
+    def TrainingLicenseNumber(cls) -> "IdentifierTypeCode":
+        """ """
         # noinspection PyCallingNonCallable
         return IdentifierTypeCode("TRL")
 
     @classproperty
-    def UnspecifiedIdentifier(cls) -> 'IdentifierTypeCode':
-        """
-        """
+    def UnspecifiedIdentifier(cls) -> "IdentifierTypeCode":
+        """ """
         # noinspection PyCallingNonCallable
         return IdentifierTypeCode("U")
 
     @classproperty
-    def UniversalDeviceIdentifier(cls) -> 'IdentifierTypeCode':
-        """
-        """
+    def UniversalDeviceIdentifier(cls) -> "IdentifierTypeCode":
+        """ """
         # noinspection PyCallingNonCallable
         return IdentifierTypeCode("UDI")
 
     @classproperty
-    def UniversalPhysicianIdentificationNumber(cls) -> 'IdentifierTypeCode':
+    def UniversalPhysicianIdentificationNumber(cls) -> "IdentifierTypeCode":
         """
         Class: Insurance
         An identifier for a provider within the CMS/Medicare program.
@@ -619,37 +590,32 @@ class IdentifierTypeCode(FhirValueSetBase):
         return IdentifierTypeCode("UPIN")
 
     @classproperty
-    def VisitNumber(cls) -> 'IdentifierTypeCode':
-        """
-        """
+    def VisitNumber(cls) -> "IdentifierTypeCode":
+        """ """
         # noinspection PyCallingNonCallable
         return IdentifierTypeCode("VN")
 
     @classproperty
-    def WICIdentifier(cls) -> 'IdentifierTypeCode':
-        """
-        """
+    def WICIdentifier(cls) -> "IdentifierTypeCode":
+        """ """
         # noinspection PyCallingNonCallable
         return IdentifierTypeCode("WC")
 
     @classproperty
-    def WorkersCompNumber(cls) -> 'IdentifierTypeCode':
-        """
-        """
+    def WorkersCompNumber(cls) -> "IdentifierTypeCode":
+        """ """
         # noinspection PyCallingNonCallable
         return IdentifierTypeCode("WCN")
 
     @classproperty
-    def HealthPlanIdentifier(cls) -> 'IdentifierTypeCode':
-        """
-        """
+    def HealthPlanIdentifier(cls) -> "IdentifierTypeCode":
+        """ """
         # noinspection PyCallingNonCallable
         return IdentifierTypeCode("XV")
 
     @classproperty
-    def OrganizationIdentifier(cls) -> 'IdentifierTypeCode':
-        """
-        """
+    def OrganizationIdentifier(cls) -> "IdentifierTypeCode":
+        """ """
         # noinspection PyCallingNonCallable
         return IdentifierTypeCode("XX")
 
