@@ -13,21 +13,22 @@ class MissingToothReasonCode(FhirValueSetBase):
     """
     https://hl7.org/FHIR/valueset-missing-tooth-reason.html
     """
+
     def __init__(self, value: AutoMapperTextInputType):
         super().__init__(value=value)
 
     # noinspection PyPep8Naming,SpellCheckingInspection
     class classproperty(object):
-        def __init__(self, f: Callable[..., 'MissingToothReasonCode']) -> None:
-            self.f: Callable[..., 'MissingToothReasonCode'] = f
+        def __init__(self, f: Callable[..., "MissingToothReasonCode"]) -> None:
+            self.f: Callable[..., "MissingToothReasonCode"] = f
 
         def __get__(
-            self, obj: Any, owner: Type['MissingToothReasonCode']
-        ) -> 'MissingToothReasonCode':
+            self, obj: Any, owner: Type["MissingToothReasonCode"]
+        ) -> "MissingToothReasonCode":
             return self.f(owner)
 
     @classproperty
-    def NameOfYourFirstValue(cls) -> 'MissingToothReasonCode':
+    def NameOfYourFirstValue(cls) -> "MissingToothReasonCode":
         """
         Comment
         """
