@@ -13,19 +13,20 @@ class LOINCCode(FhirValueSetBase):
     """
     https://www.hl7.org/fhir/valueset-observation-codes.html
     """
+
     def __init__(self, value: AutoMapperTextInputType):
         super().__init__(value=value)
 
     # noinspection PyPep8Naming,SpellCheckingInspection
     class classproperty(object):
-        def __init__(self, f: Callable[..., 'LOINCCode']) -> None:
-            self.f: Callable[..., 'LOINCCode'] = f
+        def __init__(self, f: Callable[..., "LOINCCode"]) -> None:
+            self.f: Callable[..., "LOINCCode"] = f
 
-        def __get__(self, obj: Any, owner: Type['LOINCCode']) -> 'LOINCCode':
+        def __get__(self, obj: Any, owner: Type["LOINCCode"]) -> "LOINCCode":
             return self.f(owner)
 
     @classproperty
-    def NameOfYourFirstValue(cls) -> 'LOINCCode':
+    def NameOfYourFirstValue(cls) -> "LOINCCode":
         """
         Comment
         """
