@@ -13,21 +13,22 @@ class PaymentTypeCode(FhirValueSetBase):
     """
     https://hl7.org/FHIR/valueset-ex-paymenttype.html
     """
+
     def __init__(self, value: AutoMapperTextInputType):
         super().__init__(value=value)
 
     # noinspection PyPep8Naming,SpellCheckingInspection
     class classproperty(object):
-        def __init__(self, f: Callable[..., 'PaymentTypeCode']) -> None:
-            self.f: Callable[..., 'PaymentTypeCode'] = f
+        def __init__(self, f: Callable[..., "PaymentTypeCode"]) -> None:
+            self.f: Callable[..., "PaymentTypeCode"] = f
 
         def __get__(
-            self, obj: Any, owner: Type['PaymentTypeCode']
-        ) -> 'PaymentTypeCode':
+            self, obj: Any, owner: Type["PaymentTypeCode"]
+        ) -> "PaymentTypeCode":
             return self.f(owner)
 
     @classproperty
-    def NameOfYourFirstValue(cls) -> 'PaymentTypeCode':
+    def NameOfYourFirstValue(cls) -> "PaymentTypeCode":
         """
         Comment
         """
