@@ -13,23 +13,22 @@ class ProcedurePerformerRoleCode(FhirValueSetBase):
     """
     https://hl7.org/FHIR/valueset-performer-role.html
     """
+
     def __init__(self, value: AutoMapperTextInputType):
         super().__init__(value=value)
 
     # noinspection PyPep8Naming,SpellCheckingInspection
     class classproperty(object):
-        def __init__(
-            self, f: Callable[..., 'ProcedurePerformerRoleCode']
-        ) -> None:
-            self.f: Callable[..., 'ProcedurePerformerRoleCode'] = f
+        def __init__(self, f: Callable[..., "ProcedurePerformerRoleCode"]) -> None:
+            self.f: Callable[..., "ProcedurePerformerRoleCode"] = f
 
         def __get__(
-            self, obj: Any, owner: Type['ProcedurePerformerRoleCode']
-        ) -> 'ProcedurePerformerRoleCode':
+            self, obj: Any, owner: Type["ProcedurePerformerRoleCode"]
+        ) -> "ProcedurePerformerRoleCode":
             return self.f(owner)
 
     @classproperty
-    def NameOfYourFirstValue(cls) -> 'ProcedurePerformerRoleCode':
+    def NameOfYourFirstValue(cls) -> "ProcedurePerformerRoleCode":
         """
         Comment
         """
