@@ -13,26 +13,48 @@ class RemittanceOutcomeCode(FhirValueSetBase):
     """
     https://hl7.org/FHIR/valueset-remittance-outcome.html
     """
+
     def __init__(self, value: AutoMapperTextInputType):
         super().__init__(value=value)
 
     # noinspection PyPep8Naming,SpellCheckingInspection
     class classproperty(object):
-        def __init__(self, f: Callable[..., 'RemittanceOutcomeCode']) -> None:
-            self.f: Callable[..., 'RemittanceOutcomeCode'] = f
+        def __init__(self, f: Callable[..., "RemittanceOutcomeCode"]) -> None:
+            self.f: Callable[..., "RemittanceOutcomeCode"] = f
 
         def __get__(
-            self, obj: Any, owner: Type['RemittanceOutcomeCode']
-        ) -> 'RemittanceOutcomeCode':
+            self, obj: Any, owner: Type["RemittanceOutcomeCode"]
+        ) -> "RemittanceOutcomeCode":
             return self.f(owner)
 
     @classproperty
-    def NameOfYourFirstValue(cls) -> 'RemittanceOutcomeCode':
+    def Queued(cls) -> "RemittanceOutcomeCode":
         """
-        Comment
+        The Claim/Pre-authorization/Pre-determination has been received but processing has not begun.
         """
         # noinspection PyCallingNonCallable
-        return RemittanceOutcomeCode("A")
+        return RemittanceOutcomeCode("queued")
+
+    def ProcessingComplete(cls) -> "RemittanceOutcomeCode":
+        """
+        The processing has completed without errors
+        """
+        # noinspection PyCallingNonCallable
+        return RemittanceOutcomeCode("complete")
+
+    def Error(cls) -> "RemittanceOutcomeCode":
+        """
+        One or more errors have been detected in the Claim
+        """
+        # noinspection PyCallingNonCallable
+        return RemittanceOutcomeCode("error")
+
+    def PartialProcessing(cls) -> "RemittanceOutcomeCode":
+        """
+        No errors have been detected in the Claim and some of the adjudication has been performed.
+        """
+        # noinspection PyCallingNonCallable
+        return RemittanceOutcomeCode("partial")
 
     @genericclassproperty
     def codeset(cls) -> FhirUri:
