@@ -13,21 +13,22 @@ class ServicePlaceCode(FhirValueSetBase):
     """
     https://hl7.org/FHIR/valueset-service-place.html
     """
+
     def __init__(self, value: AutoMapperTextInputType):
         super().__init__(value=value)
 
     # noinspection PyPep8Naming,SpellCheckingInspection
     class classproperty(object):
-        def __init__(self, f: Callable[..., 'ServicePlaceCode']) -> None:
-            self.f: Callable[..., 'ServicePlaceCode'] = f
+        def __init__(self, f: Callable[..., "ServicePlaceCode"]) -> None:
+            self.f: Callable[..., "ServicePlaceCode"] = f
 
         def __get__(
-            self, obj: Any, owner: Type['ServicePlaceCode']
-        ) -> 'ServicePlaceCode':
+            self, obj: Any, owner: Type["ServicePlaceCode"]
+        ) -> "ServicePlaceCode":
             return self.f(owner)
 
     @classproperty
-    def NameOfYourFirstValue(cls) -> 'ServicePlaceCode':
+    def NameOfYourFirstValue(cls) -> "ServicePlaceCode":
         """
         Comment
         """
