@@ -13,23 +13,24 @@ class SubstanceAdminSubstitutionReasonCode(FhirValueSetBase):
     """
     https://hl7.org/FHIR/v3/SubstanceAdminSubstitutionReason/vs.html
     """
+
     def __init__(self, value: AutoMapperTextInputType):
         super().__init__(value=value)
 
     # noinspection PyPep8Naming,SpellCheckingInspection
     class classproperty(object):
         def __init__(
-            self, f: Callable[..., 'SubstanceAdminSubstitutionReasonCode']
+            self, f: Callable[..., "SubstanceAdminSubstitutionReasonCode"]
         ) -> None:
-            self.f: Callable[..., 'SubstanceAdminSubstitutionReasonCode'] = f
+            self.f: Callable[..., "SubstanceAdminSubstitutionReasonCode"] = f
 
         def __get__(
-            self, obj: Any, owner: Type['SubstanceAdminSubstitutionReasonCode']
-        ) -> 'SubstanceAdminSubstitutionReasonCode':
+            self, obj: Any, owner: Type["SubstanceAdminSubstitutionReasonCode"]
+        ) -> "SubstanceAdminSubstitutionReasonCode":
             return self.f(owner)
 
     @classproperty
-    def NameOfYourFirstValue(cls) -> 'SubstanceAdminSubstitutionReasonCode':
+    def NameOfYourFirstValue(cls) -> "SubstanceAdminSubstitutionReasonCode":
         """
         Comment
         """
