@@ -13,19 +13,20 @@ class ToothCode(FhirValueSetBase):
     """
     https://hl7.org/FHIR/valueset-tooth.html
     """
+
     def __init__(self, value: AutoMapperTextInputType):
         super().__init__(value=value)
 
     # noinspection PyPep8Naming,SpellCheckingInspection
     class classproperty(object):
-        def __init__(self, f: Callable[..., 'ToothCode']) -> None:
-            self.f: Callable[..., 'ToothCode'] = f
+        def __init__(self, f: Callable[..., "ToothCode"]) -> None:
+            self.f: Callable[..., "ToothCode"] = f
 
-        def __get__(self, obj: Any, owner: Type['ToothCode']) -> 'ToothCode':
+        def __get__(self, obj: Any, owner: Type["ToothCode"]) -> "ToothCode":
             return self.f(owner)
 
     @classproperty
-    def NameOfYourFirstValue(cls) -> 'ToothCode':
+    def NameOfYourFirstValue(cls) -> "ToothCode":
         """
         Comment
         """
